==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_pb_vtrack.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_vtrack.gif"

unsigned char _mgir_gif_skin_pb_vtrack_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x09,0x00,	0x13,0x00,0xA5,0x25,0x00,0x0C,0x0C,0x0C,
	0x16,0x16,0x16,0x19,0x19,0x19,0x22,0x22,	0x22,0x32,0x32,0x32,0x34,0x34,0x34,0x35,
	0x35,0x35,0x41,0x41,0x41,0x43,0x43,0x43,	0x45,0x45,0x45,0x54,0x54,0x54,0x57,0x57,
	0x57,0x5F,0x5F,0x5F,0x65,0x65,0x65,0x68,	0x68,0x68,0x71,0x71,0x71,0x72,0x72,0x72,
	0x76,0x76,0x76,0x78,0x78,0x78,0x7E,0x7E,	0x7E,0x8E,0x8E,0x8E,0x92,0x92,0x92,0x95,
	0x95,0x95,0x9C,0x9C,0x9C,0xA8,0xA8,0xA8,	0xAA,0xAA,0xAA,0xB3,0xB3,0xB3,0xBD,0xBD,
	0xBD,0xBF,0xBF,0xBF,0xC2,0xC2,0xC2,0xC5,	0xC5,0xC5,0xC6,0xC6,0xC6,0xD1,0xD1,0xD1,
	0xD7,0xD7,0xD7,0xDE,0xDE,0xDE,0xE1,0xE1,	0xE1,0xF9,0xF9,0xF9,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x09,0x00,0x13,0x00,0x00,
	0x06,0x42,0x40,0x4D,0x43,0x91,0x38,0x30,	0x26,0x96,0x8E,0xA0,0x00,0xB9,0x78,0x3E,
	0x98,0x8A,0x04,0x10,0x22,0x59,0xAF,0x0F,	0xC0,0xE8,0x8A,0xD5,0x72,0xAD,0xD9,0xED,
	0x37,0xFC,0x25,0x91,0xC7,0x5E,0xB4,0x98,	0x7B,0x66,0xA7,0xDD,0xEB,0x6E,0x1C,0xFC,
	0x96,0x97,0xDB,0xD8,0x40,0x05,0x74,0x15,	0x6D,0x22,0x19,0x0B,0x06,0x03,0x04,0x08,
	0x0E,0x14,0x1C,0x41,0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_pb_vtrack.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_vtrack.gif"

const unsigned char _mgir_gif_skin_pb_vtrack_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x09,0x00,	0x13,0x00,0xA5,0x25,0x00,0x0C,0x0C,0x0C,
	0x16,0x16,0x16,0x19,0x19,0x19,0x22,0x22,	0x22,0x32,0x32,0x32,0x34,0x34,0x34,0x35,
	0x35,0x35,0x41,0x41,0x41,0x43,0x43,0x43,	0x45,0x45,0x45,0x54,0x54,0x54,0x57,0x57,
	0x57,0x5F,0x5F,0x5F,0x65,0x65,0x65,0x68,	0x68,0x68,0x71,0x71,0x71,0x72,0x72,0x72,
	0x76,0x76,0x76,0x78,0x78,0x78,0x7E,0x7E,	0x7E,0x8E,0x8E,0x8E,0x92,0x92,0x92,0x95,
	0x95,0x95,0x9C,0x9C,0x9C,0xA8,0xA8,0xA8,	0xAA,0xAA,0xAA,0xB3,0xB3,0xB3,0xBD,0xBD,
	0xBD,0xBF,0xBF,0xBF,0xC2,0xC2,0xC2,0xC5,	0xC5,0xC5,0xC6,0xC6,0xC6,0xD1,0xD1,0xD1,
	0xD7,0xD7,0xD7,0xDE,0xDE,0xDE,0xE1,0xE1,	0xE1,0xF9,0xF9,0xF9,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x09,0x00,0x13,0x00,0x00,
	0x06,0x42,0x40,0x4D,0x43,0x91,0x38,0x30,	0x26,0x96,0x8E,0xA0,0x00,0xB9,0x78,0x3E,
	0x98,0x8A,0x04,0x10,0x22,0x59,0xAF,0x0F,	0xC0,0xE8,0x8A,0xD5,0x72,0xAD,0xD9,0xED,
	0x37,0xFC,0x25,0x91,0xC7,0x5E,0xB4,0x98,	0x7B,0x66,0xA7,0xDD,0xEB,0x6E,0x1C,0xFC,
	0x96,0x97,0xDB,0xD8,0x40,0x05,0x74,0x15,	0x6D,0x22,0x19,0x0B,0x06,0x03,0x04,0x08,
	0x0E,0x14,0x1C,0x41,0x00,0x3B
};
#endif //_MGINCORE_RES
